@@ -100,7 +100,7 @@ async def get_ShipInfo(server_type,info,bot,ev):
                         ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
                         return '已超时退出'
             else:
-                return '找不到船'
+                return '找不到船，请确认船名是否正确，可以使用【wws 查船名】查询船只中英文'
         else:
             return '参数似乎出了问题呢'
         url = 'https://api.wows.shinoaki.com/public/wows/account/ship/info'
@@ -127,12 +127,15 @@ async def get_ShipInfo(server_type,info,bot,ev):
             return f"{result['message']}"
     except (TimeoutError, ConnectTimeout):
         logger.warning(traceback.format_exc())
+        ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
         return '请求超时了，请过会儿再尝试哦~'
     except ActionFailed:
         logger.warning(traceback.format_exc())
+        ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
         return '由于风控或禁言，无法发送消息'
     except Exception:
         logger.error(traceback.format_exc())
+        ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
         return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~'
     
     
@@ -163,14 +166,14 @@ async def get_MyShipRank_Numbers(url,server):
     try:
         data = None
         async with httpx.AsyncClient() as client:
-            resp = await client.get(url, timeout=None)
+            resp = await client.get(url, timeout=10)
             if resp.content:
                 result = resp.json()
                 page_url = str(result['url']).replace("\\","")
                 nickname = str(result['nickname'])
                 my_rank_url = f"{number_url_homes[server]}{page_url}"
                 async with httpx.AsyncClient() as client:
-                    resp = await client.get(my_rank_url, timeout=None)
+                    resp = await client.get(my_rank_url, timeout=10)
                     soup = BeautifulSoup(resp.content, 'html.parser')
                     data = soup.select_one(f'tr[data-nickname="{nickname}"]').select_one('td').string
         if data and data.isdigit():
@@ -278,7 +281,7 @@ async def get_ShipInfoRecent(server_type,info,bot,ev):
                         ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
                         return '已超时退出'
             else:
-                return '找不到船'
+                return '找不到船，请确认船名是否正确，可以使用【wws 查船名】查询船只中英文'
         else:
             return '参数似乎出了问题呢'
         url = 'https://api.wows.shinoaki.com/api/wows/recent/v2/recent/info/ship'
@@ -299,10 +302,13 @@ async def get_ShipInfoRecent(server_type,info,bot,ev):
             return f"{result['message']}"
     except (TimeoutError, ConnectTimeout):
         logger.warning(traceback.format_exc())
+        ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
         return '请求超时了，请过会儿再尝试哦~'
     except ActionFailed:
         logger.warning(traceback.format_exc())
+        ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
         return '由于风控或禁言，无法发送消息'
     except Exception:
         logger.error(traceback.format_exc())
+        ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
         return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~'
\ No newline at end of file
